#!/bin/sh
# default acpi script that takes an entry for all actions.

. '/etc/conf.d/acpid'

# check OS name with HyperbolaBSD uname.
UNAME="$(uname -s)"

acpid_ac_adapter() {
  case "${1}" in
  'plug')
    LAD="${ACPID_AP}"
    ;;
  'unplug')
    LAD="${ACPID_AU}"
    ;;
  *)
    return
    ;;
  esac

  case "${UNAME}" in
  'Linux')
    LFD="/sys/class/backlight/${ACPID_AB}"
    LBF="${LFD}/brightness"
    LMF="${LFD}/max_brightness"
    unset LFD
    printf "$((${LAD}*$(su -c 'cat '${LMF})/100))" > "${LBF}"
    unset LBF LMF
    ;;
  'HyperbolaBSD'|*)
    return
    ;;
  esac

  unset LAD
}

acpid_echo_sound() {
  _play_audio() {
    case "${1}" in
    'sndio')
      LSS="${1}"
      LSF="snd/${ACPID_SC}"
      ;;
    *)
      case "${UNAME}" in
      'Linux')
        LSS='alsa'
        LSF="hw:${ACPID_SC}"
        ;;
      'HyperbolaBSD'|*)
        LSS='oss'
        LSF="/dev/dsp${ACPID_SC}"
        ;;
      esac
      ;;
    esac

    LFD='/usr/share/sounds/freedesktop/stereo'
    LFF="${LFD}/audio-volume-change.oga"
    unset LFD

    if [ -x '/usr/bin/ffmpeg' ] && [ -f "${LFF}" ]; then
      LXC='-loglevel -8'
      ffmpeg "${LXC}" -i "${LFF}" -f "${LSS}" "${LSF}"
      unset LXC
    fi

    unset LDF LFF LSF LSS
  }

  _cksrv_and_play_audio() {
    case "${1}" in
    'openrc')
      LSC='rc-service sndiod status'
      ;;
    'runit')
      LSC='sv status sndiod'
      ;;
    esac

    case "$(${LSC})" in
    ' * status: started'|'run: sndio')
      _play_audio 'sndio'
      ;;
    *)
      _play_audio
      ;;
    esac

    unset LSC
  }

  if [ -x '/sbin/rc-service' ]; then
    _cksrv_and_play_audio 'openrc'
  elif [ -x '/usr/bin/sv' ]; then
    _cksrv_and_play_audio 'runit'
  fi
}

acpid_video_brightness() {
  case "${1}" in
  'up')
    LCB='+'
    ;;
  'down')
    LCB='-'
    ;;
  *)
    return
    ;;
  esac

  case "${UNAME}" in
  'Linux')
    LFD="/sys/class/backlight/${ACPID_AB}"
    LBF="${LFD}/brightness"
    LMF="${LFD}/max_brightness"
    unset LFD
    printf "$((${ACPID_BP}*$(su -c 'cat '${LMF})/100 ${LCB} $(cat ${LBF})))" \
      > "${LBF}"
    unset LBF LMF
    ;;
  'HyperbolaBSD'|*)
    return
    ;;
  esac

  unset LCB
}

case "${1}" in
'ac_adapter')
  case "${2}" in
  'AC'|'ACAD'|'ACPI'????':'??|'ADP'?)
    case "${4}" in
    '00000000')
      # ac pluged
      acpid_ac_adapter 'plug'
      ;;
    '00000001')
      # ac unpluged
      acpid_ac_adapter 'unplug'
      ;;
    esac
    ;;
  esac
  ;;
'battery')
  case "${2}" in
  'BAT'?|'PNP'?'C'??)
    case "${4}" in
    '00000000')
      # battery online
      ;;
    '00000001')
      # battery offline
      ;;
    esac
    ;;
  esac
  ;;
'button/lid')
  case "${3}" in
  'close')
    case "${UNAME}" in
    'Linux')
      printf "${ACPID_ST}" > '/sys/power/state'
      ;;
    esac
    ;;
  'open')
    ;;
  esac
  ;;
'button/mute')
  case "${2}" in
  'MUTE')
    case "${UNAME}" in
    'Linux')
      if [ -x '/usr/bin/amixer' ]; then
        amixer -c "${ACPID_SC}" set 'Master' toggle
      fi
      acpid_echo_sound
      ;;
    #'HyperbolaBSD'|*)
    #  if [ -x '/usr/bin/sndioctl' ]; then
    #    sndioctl -nq snd/${ACPID_SC}.mute='off'
    #  elif [ -x '/usr/sbin/mixerctl' ]; then
    #    mixerctl -qf "/dev/audioctl${ACPID_SC}" output.dac.mute='off'
    #  fi
    #  acpid_echo_sound
    #  ;;
    esac
    ;;
  esac
  ;;
'button/power')
  case "${2}" in
  'PBTN'|'PWRF')
    if [ -x '/sbin/openrc-shutdown' ]; then
      openrc-shutdown -p
    else
      poweroff -p
    fi
    ;;
  esac
  ;;
'button/sleep')
  case "${2}" in
  'SBTN'|'SLPB')
    case "${UNAME}" in
    'Linux')
      printf "${ACPID_ST}" > '/sys/power/state'
      ;;
    esac
    ;;
  esac
  ;;
'button/volumedown')
  case "${2}" in
  'VOLDN')
    case "${UNAME}" in
    'Linux')
      if [ -x '/usr/bin/amixer' ]; then
        amixer -c "${ACPID_SC}" set 'Master' "${ACPID_SP}%-"
      fi
        acpid_echo_sound
      ;;
    #'HyperbolaBSD'|*)
    #  if [ -x '/usr/bin/sndioctl' ]; then
    #    sndioctl -nq snd/${ACPID_SC}.level-="${ACPID_SP}"
    #  elif [ -x '/usr/sbin/mixerctl' ]; then
    #    mixerctl -qf "/dev/audioctl${ACPID_SC}" \
    #      output.dac.level-="${ACPID_SP}"
    #  fi
    #  acpid_echo_sound
    #  ;;
    esac
    ;;
  esac
  ;;
'button/volumeup')
  case "${2}" in
  'VOLUP')
    case "$(uname -s)" in
    'Linux')
      if [ -x '/usr/bin/amixer' ]; then
        amixer -c "${ACPID_SC}" set 'Master' "${ACPID_SP}%+"
      fi
      acpid_echo_sound
      ;;
    #'HyperbolaBSD'|*)
    #  if [ -x '/usr/bin/sndioctl' ]; then
    #    sndioctl -nq snd/${ACPID_SC}.level+="${ACPID_SP}"
    #  elif [ -x '/usr/sbin/mixerctl' ]; then
    #    mixerctl -qf "/dev/audioctl${ACPID_SC}" \
    #      output.dac.level+="${ACPID_SP}"
    #  fi
    #  acpid_echo_sound
    #  ;;
    esac
    ;;
  esac
  ;;
'jack/headphone')
  case "${2}" in
  'HEADPHONE')
    case "${3}" in
    'plug')
      ;;
    'unplug')
      ;;
    esac
    ;;
  esac
  ;;
'video/brightnessdown')
  case "${2}" in
  'BRTDN')
    acpid_video_brightness 'down'
    ;;
  esac
  ;;
'video/brightnessup')
  case "${2}" in
  'BRTUP')
    acpid_video_brightness 'up'
    ;;
  esac
  ;;
'video/switchmode')
  case "${2}" in
  'VMOD')
    ;;
  esac
  ;;
'cd/next')
  case "${2}" in
  'CDNEXT')
    ;;
  esac
  ;;
'cd/play')
  case "${2}" in
  'CDPLAY')
    # It is disabled, because it is not supported with multimedia keys and
    # it was not tested.
    #if [ -x '/usr/bin/mpv' ]; then
    #  mpv 'cdda://:1' -cache '1024'
    #elif [ -x '/usr/bin/mplayer' ]; then
    #  mplayer 'cdda://:1' -cache '1024'
    #fi
    ;;
  esac
  ;;
'cd/prev')
  case "${2}" in
  'CDPREV')
    ;;
  esac
  ;;
'cd/stop')
  case "${2}" in
  'CDSTOP')
    ;;
  esac
  ;;
esac
